%define name            cryptsetup
%define version         2.0.4
%define release         %mkrel 1
%define subver          %{nil}
%define major		12
%define libname		%mklibname cryptsetup %major
%define dlibname	%mklibname cryptsetup -d

%bcond_with compatible
%bcond_with static


Name:		%{name}
Version:	%{version}
Release:	%{release}
Summary:	Utility for setting up encrypted filesystems
Summary(de):	Werkzeug zum Einrichten von verschlüsselten Dateisystemen
License:	GPLv2
Group:		System/Base
URL:		https://gitlab.com/cryptsetup/cryptsetup
Source0:	https://www.kernel.org/pub/linux/utils/cryptsetup/v1.6/%{name}-%{version}%{subver}.tar.xz
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires:	libgcrypt-devel >= 1.1.42
BuildRequires:	libgpg-error-devel
BuildRequires:	libdevmapper-devel
BuildRequires:	libuuid-devel
BuildRequires:	libpopt-devel
BuildRequires:	libargon2-devel
BuildRequires:	json-c-devel
BuildRequires:	libblkid-devel
%if %{with static}
BuildRequires:	glibc-static-devel
%endif
Obsoletes:	cryptsetup-luks < 1.0.5
Provides:	cryptsetup-luks = %{version}-%{release}

%description
LUKS is the upcoming standard for Linux hard disk encryption. 
By providing a standard on-disk-format, it does not only facilitate 
compatibility among distributions, but also provide secure management 
of multiple user passwords. In contrast to existing solution, LUKS stores 
all setup necessary setup information in the partition header, enabling 
the user to transport or migrate his data seamlessly.
LUKS for dm-crypt is implemented in cryptsetup. cryptsetup-luks is
as a complete replacement for the original cryptsetup. It provides all the 
functionally of the original version plus all LUKS features, that are 
accessible by luks* action.

#german
%description -l de
LUKS ist der kommende Standard für die Linux Festplattenverschlüsselung.
Durch das anbieten eines Standard on-Disk-Formats, erleichtert es nicht nur 
die Kompatibilität zwischen den Distributionen, sondern bietet auch sichere 
Verwaltung von mehreren Benutzerkennwörtern. Im Gegensatz zur vorhandenen 
Lösung speichert LUKS alle für die Einrichtung benötigten Informationen im
Partitionsheader, dies ermöglicht dem Benutzer seine 
Daten problemlos zu transportieren oder migrieren.

%package -n	%libname
Summary:	Library for setting up encrypted filesystems
Summary(de):	Bibliothek zum Einrichten von verschlüsselten Dateisystemen
Group:		System/Libraries

%description -n %libname
LUKS is the upcoming standard for Linux hard disk encryption.
By providing a standard on-disk-format, it does not only facilitate
compatibility among distributions, but also provide secure management
of multiple user passwords. In contrast to existing solution, LUKS stores
all setup necessary setup information in the partition header, enabling
the user to transport or migrate his data seamlessly.

This package contains the shared libraries required for running
programs which use cryptsetup-luks.
#german
%description -n %libname -l de
LUKS ist der kommende Standard für die Linux Festplattenverschlüsselung.
Durch das anbieten eines Standard on-Disk-Formats, erleichtert es nicht nur 
die Kompatibilität zwischen den Distributionen, sondern bietet auch sichere 
Verwaltung von mehreren Benutzerkennwörtern. Im Gegensatz zur vorhandenen 
Lösung speichert LUKS alle für die Einrichtung benötigten Informationen im
Partitionsheader, dies ermöglicht dem Benutzer seine 
Daten problemlos zu transportieren oder migrieren.

Dieses Paket enthält die gemeinsam verwendeten Bibliotheken, die zum Ausführen 
von Programmen unter Verwendung von cryptsetup-luks benötigt werden.


%package -n	%dlibname
Summary:	Development library for setting up encrypted filesystems
Summary(de):	Entwicklerdateien für das Erstellen verschlüsselten Dateiensysteme
Group:		Development/Libraries
Requires:	%libname = %{version}-%{release}
Provides:	cryptsetup-devel
Provides:	%name-devel = %{version}-%{release}
Obsoletes:	%mklibname -d cryptsetup 0

%description -n %dlibname
LUKS is the upcoming standard for Linux hard disk encryption.
By providing a standard on-disk-format, it does not only facilitate
compatibility among distributions, but also provide secure management
of multiple user passwords. In contrast to existing solution, LUKS stores
all setup necessary setup information in the partition header, enabling
the user to transport or migrate his data seamlessly.

This package contains the header files and development libraries
for building programs which use cryptsetup-luks.
#german
%description -n %dlibname -l de
LUKS ist der kommende Standard für die Linux Festplattenverschlüsselung.
Durch das anbieten eines Standard on-Disk-Formats, erleichtert es nicht nur 
die Kompatibilität zwischen den Distributionen, sondern bietet auch sichere 
Verwaltung von mehreren Benutzerkennwörtern. Im Gegensatz zur vorhandenen 
Lösung speichert LUKS alle für die Einrichtung benötigten Informationen im
Partitionsheader, dies ermöglicht dem Benutzer seine 
Daten problemlos zu transportieren oder migrieren.

Dieses Paket stellt die zur Entwicklung benötigten Header und Bibliotheken 
zur Verfügung um Programme die cryptsetup-luks verwenden zu entwickeln.

%prep
%setup -q -n %{name}-%{version}%{subver}

chmod -x python/pycryptsetup-test.py
chmod -x misc/dracut_90reencrypt/*

iconv -f ISO-8859-1 -t UTF8 ChangeLog -o ChangeLog.new
mv -f ChangeLog.new ChangeLog

%build
%configure2_5x --disable-selinux --sbindir=/sbin --enable-libargon2 \
%if %{with static}
	--enable-static-cryptsetup \
%endif
%if %{with compatible}
	--with-plain-mode=cbc-plain --with-luks1-keybits=128 \
%endif
# end of configure

# remove rpath
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

%make

%install
rm -rf %{buildroot}
%makeinstall_std

%find_lang %{name}
%if %{with static}
%else
rm -f %{buildroot}%{_libdir}/libcryptsetup.la
%endif

%clean
rm -rf %{buildroot}
rm -rf $RPM_BUILD_DIR/%{name}-%{version}

%files -f %name.lang
%defattr(-,root,root)
%doc ChangeLog AUTHORS FAQ INSTALL NEWS README TODO
%{_mandir}/man8/cryptsetup.8*
%{_mandir}/man8/cryptsetup-reencrypt.8*
%{_mandir}/man8/integritysetup.8*
%{_mandir}/man8/veritysetup.8*
/sbin/cryptsetup
/sbin/cryptsetup-reencrypt
/sbin/integritysetup
/sbin/veritysetup

%files -n %dlibname
%{_includedir}/libcryptsetup.h
%if %{with static}
%{_libdir}/libcryptsetup.a
%{_libdir}/libcryptsetup.la
%endif
%{_libdir}/libcryptsetup.so
%{_libdir}/pkgconfig/libcryptsetup.pc

%files -n %libname
/%{_libdir}/libcryptsetup.so.%{major}*


%changelog
* Sun Oct 21 2018 adrianomorselli <adrianomorselli> 2.0.4-1uplos2018
- update
- add BR libblkid-devel
